<?php
/** Runa shimi (Runa shimi)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author AlimanRuna
 * @author Ebe123
 * @author Sylvain2803
 */

$fallback = 'qu, es';

$namespaceNames = array(
	NS_MEDIA            => 'Midya',
	NS_SPECIAL          => 'Sapak',
	NS_TALK             => 'Rimanakuy',
	NS_USER             => 'Rurak',
	NS_USER_TALK        => 'Rurakpa_rimanakuy',
	NS_PROJECT_TALK     => '$1-pa_rimanakuy',
	NS_FILE             => 'Rikcha',
	NS_FILE_TALK        => 'Rikchapa_rimanakuy',
	NS_MEDIAWIKI        => 'MediaWiki',
	NS_MEDIAWIKI_TALK   => 'MediaWikipa_rimanakuy',
	NS_TEMPLATE         => 'Plantilla',
	NS_TEMPLATE_TALK    => 'Plantillapa_rimanakuy',
	NS_HELP             => 'Yanapa',
	NS_HELP_TALK        => 'Yanapapak_rimanakuy',
	NS_CATEGORY         => 'Samiyachiy',
	NS_CATEGORY_TALK    => 'Samiyachiy_rimanakuy',
);

$messages = array(
# User preference toggles
'tog-underline'              => 'Tinkikunana uraypi aspishpa rikuchina',
'tog-highlightbroken'        => 'Pakishka tinkikuna <a href="" class="new">kashna</a> (mana kashna munakpika, kashnami<a href="" class="internal">?</a>rikuchinata munapankimi)',
'tog-justify'                => 'Aspinakunata alli paktachina',
'tog-hideminor'              => 'mushuk killkaykunapak kamupi, uchilla killkaykunata pakana',
'tog-hidepatrolled'          => 'mushuk killkaykunapak kamupi, ña rikushka killkaykunata pakana',
'tog-newpageshidepatrolled'  => 'Mushuk pankakunapak kamupi, ña rikushka pankakunata pakana',
'tog-extendwatchlist'        => 'Rikushka pankakunapak mushuk killkaykunapak kamupi, ama yallik mushuk killkaykunatalla rikuchina, tukuykunatami rikuchina',
'tog-usenewrc'               => 'Mushuk killkaykunata chapashka pankakunapak killkaykunatapash ashtawan alli rikuchina (Javascriptwanlla)',
'tog-numberheadings'         => 'Uma killkaykunata yupayta churak antawata llankachina',
'tog-showtoolbar'            => 'Llamkana antakunata rikuchina (Javascriptwanlla)',
'tog-editondblclick'         => 'Ishkayta klik rurashpa pankapi killkanata kallarina (JavaScriptwanlla)',
'tog-editsection'            => 'Rakikunata [Killkana] tinkiwan killkankapak arinina',
'tog-rememberpassword'       => 'Ñukapak shuti, yaykuna yupaytapash kay wampunapi kipaka churankapak yuyana ({{PLURAL:$1|puncha|punchakuna}}kamanlla)',
'tog-watchcreations'         => 'Ñukapak wacharishka pankakunata rikuna',
'tog-watchdefault'           => 'Ñukapak shukchishka pankakunata rikuna',
'tog-watchmoves'             => 'Ñukapak shuk shutiman apakushka pankakunata rikuna',
'tog-watchdeletion'          => 'Ñukapak pichashka pankakunata rikuna',
'tog-minordefault'           => 'Nimata nikpika, ñukapak killkaykunata uchillami nina',
'tog-previewontop'           => 'Ñauwpak rikuchik pankata killkana pankapak hawapi churana',
'tog-nocache'                => 'Wampunapi ama rikushka pankakunata yuyana',
'tog-enotifwatchlistpages'   => 'Shuk rikushka pankata shukchishka kakpika, e-chaskita kachamushpami willaway',
'tog-enotifusertalkpages'    => 'Ñukapak rimana pankapi mushuk killkayta tiyakpi, e-chaskiwan willaway',
'tog-enotifminoredits'       => 'Mushuk killkayta uchilla kakpipash e-chaskiwan willaway',
'tog-shownumberswatching'    => 'Mashna rurakkunaka chay pankata rikukuncha rikuchina',
'tog-oldsig'                 => 'Kunan pachapak aspina:',
'tog-fancysig'               => 'aspinata Wiki-killkay shina rikuchina (mana ñapash tinkita churashpa)',
'tog-showjumplinks'          => '"chayman kallpana" tinkikunata sakina',
'tog-forceeditsummary'       => 'Mana uchilla willayta churashpa killkakpi willaway',
'tog-watchlisthideown'       => 'Rikushka pankakunapak mushuk killkaykunapi, ñukapak killkaykunata mana rikuchina',
'tog-watchlisthidebots'      => 'Rikushka pankakunapak mushuk killkaykunapi, antawakunapak killkaykunata mana rikuchina',
'tog-watchlisthideminor'     => 'Rikushka pankakunapak mushuk killkaykunapi, uchilla killkaykunata mana rikuchina',
'tog-watchlisthideliu'       => 'Rikushka pankakunapak mushuk killkaykunapi, shutiyuk rurakkunapak killkaykunata mana rikuchina',
'tog-watchlisthideanons'     => 'Rikushka pankakunapak mushuk killkaykunapi, shuti illak rurakkunapak killkaykunata mana rikuchina',
'tog-watchlisthidepatrolled' => 'Rikushka pankakunapak mushuk killkaykunapi, ña rikushka killkaykunata mana rikuchina',
'tog-ccmeonemails'           => 'ñuka shuk rurakman e-chaskita kachakpi, ñukapakmanpash kachamuna',
'tog-diffonly'               => 'Mushuk killkaykunapak uraypi, pankata ama rikuchiychu',
'tog-showhiddencats'         => 'Pakashka katikuriyakunata rikuchina',

'underline-always' => 'Wiñay',
'underline-never'  => 'Nimamanta',

# Dates
'sunday'        => 'Hawkay',
'monday'        => 'Sullka',
'tuesday'       => 'Kulla',
'wednesday'     => 'Haway',
'thursday'      => 'Patma',
'friday'        => 'Haycha',
'saturday'      => 'Tinki',
'sun'           => 'Dom',
'mon'           => 'Lun',
'tue'           => 'Mar',
'wed'           => 'Mie',
'thu'           => 'Jue',
'fri'           => 'Vie',
'sat'           => 'Sab',
'january'       => 'Kamay',
'february'      => 'Panchiy',
'march'         => 'Pawkar',
'april'         => 'Ayriwa',
'may_long'      => 'Aymuray',
'june'          => 'Inti',
'july'          => 'Purun',
'august'        => 'Chakmay',
'september'     => 'Kuya',
'october'       => 'Yaku',
'november'      => 'Ayar',
'december'      => 'Kapak',
'january-gen'   => 'Kamay',
'february-gen'  => 'Panchiy',
'march-gen'     => 'Pawkar',
'april-gen'     => 'Ayriwa',
'may-gen'       => 'Aymuray',
'june-gen'      => 'Inti',
'july-gen'      => 'Purun',
'august-gen'    => 'Chakmay',
'september-gen' => 'Kuya',
'october-gen'   => 'Yaku',
'november-gen'  => 'Ayar',
'december-gen'  => 'Kapak',
'jan'           => 'Kam',
'feb'           => 'Pan',
'mar'           => 'Paw',
'apr'           => 'Ayri',
'may'           => 'Aymu',
'jun'           => 'Inti',
'jul'           => 'Pur',
'aug'           => 'Chak',
'sep'           => 'Kuya',
'oct'           => 'Yaku',
'nov'           => 'Ayar',
'dec'           => 'Kap',

# Categories related messages
'pagecategories'                 => '{{PLURAL:$1|Katiguriya|Katiguriyakuna}}',
'category_header'                => '"$1" katiguriyapi tiyak pankakuna',
'subcategories'                  => 'Uchilla katikuriyakuna',
'category-media-header'          => '"$1" katiguriyapi tiyak archiwukuna',
'category-empty'                 => "''Kay katiguriyapi nimata tiyanchu.''",
'hidden-categories'              => '{{PLURAL:$1|Pakashka katiguriya|Pakashka katiguriyakuna}}',
'hidden-category-category'       => 'Pakashka katikuriyakuna',
'category-subcat-count'          => '{{PLURAL:$2|Kay katikuriyaka shuklla ushi katikuriyata charin :|Kay katiguriyaka kay katik {{PLURAL:$1|ushi katikuriyata|$1 ushi katikuriyakunata}} charinmi, $2-pura.}}',
'category-subcat-count-limited'  => 'Kay katikuriyaya {{PLURAL:$1|shuk ushi katikuriya|$1 ushi katikuriyakuna}} charinmi:',
'category-article-count'         => '{{PLURAL:$2|Kay katiguriyapi shuklla pankaka tiyanmi.|Kay katiguriyapi kay katik {{PLURAL:$1|panka|$1 pankakunaka}} tiyanmi, $2-pura.}}',
'category-article-count-limited' => 'Kay katiguriyapika, kay katik {{PLURAL:$1|pankami|$1 pankakunami}} tiyan.',
'category-file-count'            => '{{PLURAL:$2|Kay katiguriyapi shuklla archiwuka tiyanmi.|Kay katiguriyapi kay katik {{PLURAL:$1|archiwu|$1 archiwukunaka}} tiyanmi, $2-pura.}}',
'category-file-count-limited'    => 'Kay katiguriyapika, kay katik {{PLURAL:$1|archivumi|$1 archivukunami}} tiyan.',
'listingcontinuesabbrev'         => 'katiy',
'noindex-category'               => 'Googlepak pakashka pankakuna (__NOINDEX__ charik pankakuna)',
'broken-file-category'           => 'Pakishka archivukunaman tinkiyuk pankakuna',

'about'         => 'Pankamanta',
'article'       => 'Yachaykunayuk panka',
'newwindow'     => '(Shuk mushuk wintanapi pakan)',
'cancel'        => 'Ama nina',
'moredotdotdot' => 'Ashtawan...',
'mypage'        => 'Ñukapak panka',
'mytalk'        => 'Ñukapak rimanakuy',
'anontalk'      => 'Kay IP yupaypak rimana',
'navigation'    => 'Wampuna',

# Cologne Blue skin
'qbfind'         => 'Maskana',
'qbbrowse'       => 'Maskana',
'qbedit'         => 'Killkana',
'qbpageoptions'  => 'Pankapak akllanakuna',
'qbpageinfo'     => 'Pankamanta willaykuna',
'qbmyoptions'    => 'Ñukapak pankakuna',
'qbspecialpages' => 'mans shukkunashina pankakuna',
'faq'            => 'Ashtawan tapushkaka tapunakuna',
'faqpage'        => 'Project:ashta ministishka tapuykuna',

# Vector skin
'vector-action-addsection'       => 'Shuk mushuk rimanakuyta kallarina',
'vector-action-delete'           => 'Pichana',
'vector-action-move'             => 'Apakuna',
'vector-action-protect'          => 'Harkana',
'vector-action-undelete'         => 'Kutin wacharichina',
'vector-action-unprotect'        => 'Harkayta shukchina',
'vector-simplesearch-preference' => 'Ashtawan alli maskankapak imakunata arinina (Vectorwanlla)',
'vector-view-create'             => 'Kamarina',
'vector-view-edit'               => 'Killkana',
'vector-view-history'            => 'Wiñay kawsayta rikuna',
'vector-view-view'               => 'Killkakatina',
'vector-view-viewsource'         => 'Pukyu killkata rikuna',
'actions'                        => 'Ruraykuna',
'namespaces'                     => 'Shutipak kitikuna',
'variants'                       => 'Shuk rikuchiy shinakuna',

'errorpagetitle'    => 'Pantay',
'returnto'          => '$1-man tikramuna.',
'tagline'           => '{{SITENAME}}manta',
'help'              => 'Yanapa',
'search'            => 'Maskana',
'searchbutton'      => 'Maskana',
'go'                => 'Rina',
'searcharticle'     => 'Rina',
'history'           => 'Wiñay kawsay',
'history_short'     => 'Wiñay kawsay',
'updatedmarker'     => 'Ñukapak yallik kipak shamushka kipa shukchishka',
'printableversion'  => 'Impresoraman pankakuna',
'permalink'         => 'Enlace permanente',
'print'             => 'Papelpi llukshina',
'view'              => 'Rikuna',
'edit'              => 'killkana',
'create'            => 'Kamarina',
'editthispage'      => 'Kay pankapi killkana',
'create-this-page'  => 'Kay pankata kallarina',
'delete'            => 'pichay',
'deletethispage'    => 'Kay pankata pichana',
'undelete_short'    => 'Kutin chay {{PLURAL:$1|killkayta|$1 killkaykunata}} churana',
'viewdeleted_short' => '{{PLURAL:$1|shuk pichashka killkayta|$1 pichashka killkaykunata}} rikuna',
'protect'           => 'Wichkana',
'protect_change'    => 'Shukchina',
'protectthispage'   => 'Kay pankata harkana',
'unprotect'         => 'Harkayta shukchina',
'unprotectthispage' => 'Kay pankapak harkayta shukchina',
'newpage'           => 'Mushuk panka',
'talkpage'          => 'Kay pankamanta rimanakuna',
'talkpagelinktext'  => 'Rimanakuy',
'specialpage'       => 'Mana shukkunashina panka',
'personaltools'     => 'Kikinpak llankanaman yanapanakuna',
'postcomment'       => 'Mushuk raki',
'articlepage'       => 'Pankata rikuna',
'talk'              => 'Rimanakuna',
'views'             => 'Rikunakuna',
'toolbox'           => 'Llankanakuna',
'userpage'          => 'Chay rurakpa pankata rikuna',
'projectpage'       => 'Ruraykamay pankata rikuna',
'imagepage'         => 'Kay archivupak pankata rikuna',
'mediawikipage'     => 'Willay pankata rikuna',
'templatepage'      => 'Plantillapak pankata rikuna',
'viewhelppage'      => 'Ayudana pankata rikuna',
'categorypage'      => 'Katiguriya pankata rikuna',
'viewtalkpage'      => 'Rimanakuyta rikuna',
'otherlanguages'    => 'Shuk shimikunapi',
'redirectedfrom'    => '($1-manta pushashka)',
'redirectpagesub'   => 'pushashka panka',
'lastmodifiedat'    => 'Kay pankata $1 punchapi, $2 pachapi kutin llankashkami karka',
'viewcount'         => 'Kay pankaka ñami  {{PLURAL:$1|una vezta|$1 vecesta}} rikushkami karka',
'protectedpage'     => 'Harkashka panka',
'jumpto'            => 'Chayman rina',
'jumptonavigation'  => 'Wampuna',
'jumptosearch'      => 'Maskana',
'view-pool-error'   => 'Atatay, kunan ratupi pankayuk antawakuna yapa trabajuta charinmi. 
Yapa runakuna kay pankata rikukunmi.
Ama shinachu kapay, ashakuta shuyapay, kipalla kutin pankata rikunkapak shamupay.

$1',
'pool-timeout'      => 'Harkankapak tiempota ña tukurishka',
'pool-queuefull'    => 'Lankankapak suyana uku ña huntashkami',
'pool-errorunknown' => 'Na riksishka pantay',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => '{{SITENAME}}manta',
'aboutpage'            => 'Project:{{SITENAME}}manta',
'copyright'            => 'Kay panka hawapi, $1 killkakunapak hayñikunaka tiyanmi',
'copyrightpage'        => '{{ns:project}}:Killkakpa hayñikuna',
'currentevents'        => 'Kunan pacha',
'currentevents-url'    => 'Project:Kunan pacha',
'disclaimers'          => 'Kamachikmanta willaykuna',
'disclaimerpage'       => 'Project:Kamachikmanta kapak willaykuna',
'edithelp'             => 'Llankanapaa yanapa',
'edithelppage'         => 'Help:Imashina killkankapa yanapana ?',
'helppage'             => 'Help:Yanapa',
'mainpage'             => 'Kapak Panka',
'mainpage-description' => 'Kapak panka',
'policy-url'           => 'Project:Kamachiykuna',
'portal'               => 'Ayllupak panka',
'portal-url'           => 'Project:Ayllupak panka',
'privacy'              => 'Willakunata amachaynin',
'privacypage'          => 'Project:Kampak willaykunawan imata ruranchik ?',

'badaccess'        => 'Pita sakina nishka pantay tiyarka',
'badaccess-group0' => 'Shuk imata ruranata munapanki, kayta rurankapak na sakinata ushanchikchu.',
'badaccess-groups' => 'Ima kanka ruranata munanki, {{PLURAL:$2|Kay grupopak|Kay $2 grupokunapak}} runakunalla ruranata ushan: $1',

'versionrequired'     => 'Kayta Mediawiki $1 nishkawanlla ruranata ushapanki.',
'versionrequiredtext' => 'Kayta Mediawiki $1 nishkawanlla ruranata ushapanki. Ashtawan yachakunkapak, [[Special:Version|version page]] pankata rikukripay.',

'ok'                      => 'Ari nina',
'retrievedfrom'           => '$1 pankamanta hapishka',
'youhavenewmessages'      => '$1 charipanki ($2).',
'newmessageslink'         => 'Mushuk willaymi',
'newmessagesdifflink'     => 'yalli mushuk killkay',
'youhavenewmessagesmulti' => '$1-pi mushuk chaskikunata charipankimi.',
'editsection'             => 'Killkana',
'editold'                 => 'Killkana',
'viewsourceold'           => 'Pukyu killkata rikuna',
'editlink'                => 'Killkana',
'viewsourcelink'          => 'Pukyu killkata rikuna',
'editsectionhint'         => '$1 Seccionpi llankana',
'toc'                     => 'Tiyakkuna',
'showtoc'                 => 'Rikuchina',
'hidetoc'                 => 'Pakana',
'collapsible-collapse'    => 'Allichina',
'collapsible-expand'      => 'Rikuchina',
'thisisdeleted'           => '$1-ta rikunallacha, kutin ruranapashcha munapanki ?',
'viewdeleted'             => '$1 pankata rikunata munapanki ?',
'restorelink'             => '{{PLURAL:$1|shuk pichashka killkayta|$1 pichashka killkaykunata}} rikuna',
'feedlinks'               => 'Mikuchiy',
'feed-invalid'            => 'Willaykunata mikuchik antawapak llankachinkapak, nallita akllarkapankichu.',
'site-rss-feed'           => '$1 RSS pukyu',
'site-atom-feed'          => "$1 ''Atom'' pukuy",
'page-rss-feed'           => '$1 RSS pukyu',
'page-atom-feed'          => '$1 Atom feed',
'red-link-title'          => '$1 (illakmi panka)',
'sort-descending'         => 'Hawamanta urayman imakunata tiyachina',
'sort-ascending'          => 'Uraymanta hawaman imakunata tiyachina',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Panka',
'nstab-user'      => 'Rurakpa panka',
'nstab-media'     => 'Media',
'nstab-special'   => 'Sapak pankakuna',
'nstab-project'   => 'Ruraykamaypa panka',
'nstab-image'     => 'Archivu',
'nstab-mediawiki' => 'Willay',
'nstab-template'  => 'Plantilla',
'nstab-help'      => 'Ayuda',
'nstab-category'  => 'Uwarullkay',

# Main script and global functions
'nosuchaction' => 'Kay rurayta illanmi',

# General errors
'error'                => 'Pantay',
'databaseerror'        => 'Yachayyuk ukupi pantay',
'laggedslavemode'      => "'''Rikupay''': Kay pankapi, shina kakpi, mushuk killkaykuna illankacha.",
'missing-article'      => "Hatun kamupi shuk killkayta mana tarin, shinapash chay killkayta tiyanami kan. Paypa chay shutima kan : «$1» $2.
Icha shuk ñawpak pachamanta ''diff'' ñamana tiyanchu, icha kay tinkika shuk pichashka pankapa shutimi kan. 
Mana shina kakpi, shuk [[Special:ListUsers/sysop|kamachyik]]man willapay, payta URL killkata willapay.",
'missingarticle-rev'   => '(Killkay#: $1)',
'internalerror'        => 'Antawa ukupi pantay tiyarka',
'internalerror_info'   => 'Antawa ukupi pantay tiyarka: $1',
'fileappenderrorread'  => 'Pankata wiñachishpa $1-ta na tarinata usharkanchikchu',
'fileappenderror'      => '$1-ta $2-man yapanata na atirkanchikchu',
'filecopyerror'        => '$1-ta $2-man ishkachanata na atirkanchikchu',
'filerenameerror'      => '$1-man $2 shutita karana na atirkanchikchu',
'filedeleteerror'      => '"$1" archivuta pichanata na atirkanchikchu.',
'directorycreateerror' => '$1 allichina ukuta na wachachinata atirkanchikchu',
'filenotfound'         => '"$1" archivuta tarinata na atirkanchikchu.',
'fileexistserror'      => '$1 archivupi na killkanata ushapankichu: shuk shina shutiyuk archivuta ñami tiyan',
'unexpected'           => 'Chayta na shuyashkachu karka: "$1"="$2".',
'badarticleerror'      => 'Kay pankapi chayta na ruranachu.',
'cannotdelete'         => '$1 shutiyuk pankata (archivucha) na pichanata atirkanchikchu.
Shina kakpika, shuk rurakka ña pankata pichankacha.',
'badtitle'             => 'Pankapa shutika mana allichu',
'badtitletext'         => 'Kay pankapa shutika mana allichu, icha illakmi kan. Icha mana alli llikata charin.',
'viewsource'           => 'Pukyu killkata rikuna',
'actionthrottled'      => 'Rurayta harkashka',
'actionthrottledtext'  => 'Spam rurashpa nalli runakunaka ama yapata chaskikuna kachankapak, mana chayta kutin ñapash rurana ushapankichu. Ama shinachu kapay, ashata shuyashpa  (wakin minutoskuna) kutin rurapay.',
'protectedpagetext'    => 'Kay pankaka ama shukchinkapak harkashkami kan.',
'viewsourcetext'       => 'Kay pankapak wiki killkayta rikunata, ishkachinatapash ushapankimi.',
'protectedinterface'   => 'Kay pankaka kapak willaykunata charinmi, ama nalli runakunaka kaypi killkankapak harkashkami kapan.',

# Login and logout pages
'yourname'                => 'Rurak shuti:',
'yourpassword'            => 'Yaykunkapak rimay:',
'yourpasswordagain'       => 'Yaykunapak rimayta kutin killkapay:',
'remembermypassword'      => 'Kay Internet-wampunapi {{PLURAL:$1|shuk punchata|$1 punchakunata}} ñuka rurak shutiwan yaykushkami katichiwapay.',
'login'                   => 'Yaykuna',
'nav-login-createaccount' => 'Yaykuna',
'loginprompt'             => '{{SITENAME}}man yaykunkapak <i>cookies</i>-man ari ninami kapanki.',
'userlogin'               => 'Yaykuna',
'logout'                  => 'Llukshina',
'userlogout'              => 'Llukshina',
'nologin'                 => "Mana rurak shutita charinchu ? '''$1'''.",
'nologinlink'             => 'Shuk rurak shutita akllana',
'createaccount'           => 'Shuk rurak shutita akllana',
'gotaccount'              => "Ñachu rurak shutita charinchu ? '''$1'''.",
'gotaccountlink'          => 'Yaykuna',
'userlogin-resetlink'     => 'Kikinpa yaykunaman yuyaykunata kunkapankichu ?',
'mailmypassword'          => 'Musuq yaykunkapak rimayta e-chaskiwan kachawapay',
'loginlanguagelabel'      => 'Shimi: $1',

# Edit page toolbar
'bold_sample'     => 'Yanayashka killka',
'bold_tip'        => 'Yanayashka killka',
'italic_sample'   => 'Wiksu killka',
'italic_tip'      => 'Wiksu qillqa',
'link_sample'     => 'Tinkipak uma rimay',
'link_tip'        => 'Ukuman tinki',
'extlink_sample'  => 'http://www.example.com tinkipa uma rimay',
'extlink_tip'     => 'Hawaman tinki (http:// llikakunawan kallarinami kan)',
'headline_sample' => 'Uma rimaypa killka',
'headline_tip'    => 'Ishkay-niki hatun uma rimay',
'nowiki_sample'   => "Kaypi wiki-shimi illak (''sin formato'') killkaykunata churapay",
'nowiki_tip'      => 'wiki-shimi ama hapinchu',
'image_tip'       => 'Ukupi tiyak rikcha',
'media_tip'       => 'Archivuman tinkikuna',
'sig_tip'         => 'Kikinpa aspiyta, punchawan pachawanpash killkan',
'hr_tip'          => 'sirik aspi (paykunata ama ashtawan churapay)',

# Edit pages
'summary'                          => 'Uchilla rimay',
'subject'                          => 'Imamanta/Uma rimay',
'minoredit'                        => 'Kay killkayka uchillami kan',
'watchthis'                        => 'Kay pankata rikukuna',
'savearticle'                      => 'Pankata churana',
'preview'                          => 'Ñawpak rikuy',
'showpreview'                      => 'Ñawpak rikuchina',
'showdiff'                         => 'Mushuk killkaykunata rikuchina',
'anoneditwarning'                  => "'''Rikupay:''' kikinpa mana rurak shutiwan yaykurkapanki, shina kakpika kikinpa IP yupaykunaka kay pankapa wiñay kawsaypi tiyankami .",
'newarticle'                       => '(Mushuk)',
'newarticletext'                   => 'Shuk illak pankaman tinkita katirkapanki. Kay pankata kamankapak uraypi killkapay. Ashtawan yachakunkapak [[{{MediaWiki:Helppage}}|yanapana pankata]] rikupay. Mana chay pankata kamanata munakpika, ñawpa pankaman kutin ripay.',
'noarticletext'                    => 'Kunan pachapi, kay pankaka mana killkaykunata charin.
Pakpak shutita [[Special:Search/{{PAGENAME}}|shuk pankakunapi maskanata]], <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} registroskunapi maskanata]pash ushankimi, kutin [{{fullurl:{{FULLPAGENAME}}|action=edit}} kay pankata kamarinata] ushankimi',
'noarticletext-nopermission'       => 'Kunan pachapi kay pankaka mana killkashkakunata charinchu. Paypak shutita [[Special:Search/{{PAGENAME}}|shuk pankakunapi maskanata]] ushapankimi, shinalla <span class="plainlinks">pankakunapa wiñay kawsay kamupi [{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} tinkishka shukchiykunaka] maskana</span>',
'previewnote'                      => 'Rikupay: kay killkaykunata nara allichipashkankichu !',
'editing'                          => '$1 pankapi killkashpa',
'editingsection'                   => '$1 rakipi killkashpa',
'templatesused'                    => 'Kay pankaka {{PLURAL:$1|plantilla|plantillakuna}}ta llankachin:',
'templatesusedpreview'             => 'Kay ñawpak rikuchiyka {{PLURAL:$1|plantilla|plantillakuna}}ta llankachin:',
'template-protected'               => 'allichishka',
'template-semiprotected'           => 'chawpilla wichkashka',
'hiddencategories'                 => 'Kay pankaka {{PLURAL:$1|shuk pakashka samiyachiypimi|$1 pakashka samiyachiykunapimi}} kan:',
'permissionserrorstext-withaction' => 'Mana $2ta ushapankichu, {{PLURAL:$1|imamanta|imakunamanta}}:',
'recreate-moveddeleted-warn'       => "'''Rikupay''': shuk pichashkamari pankata kutin kamachikupanki !


Tapuripay, kaypi killkanata allimi, mana allimi kanchu.
Uraypi apakunakunapa pichanakunapa kamuta rikuchiwanchik:",
'moveddeleted-notice'              => 'Kaypankaka pichashkami kan. 
Uraypi apakuykunpa, pichaykunapa kamuta rikuchinchik:',

# Parser/template warnings
'post-expand-template-inclusion-warning'  => 'Rikupay: plantillaskunaka ashtawan hatunmi kan. Wakin plantillakunata mana churashkami kanka.',
'post-expand-template-inclusion-category' => 'Ashtawan plantillakunayuk pankakuna',
'post-expand-template-argument-warning'   => "'''Rikupay''': Kay pankaka shuk ashtawan llashak plantillaman kachashka rimayta charin.
Kay (kaykunachu) kachashkakunaka cunkashkami kashka.",
'post-expand-template-argument-category'  => 'Cunkashka plantillaman kachashkakunata charishpaka pankakuna',

# History pages
'viewpagelogs'           => 'Kay pankapa kamukunata rikuna',
'currentrev-asof'        => '$1 pachamanta kunan killkay',
'revisionasof'           => '$1-pa panka',
'revision-info'          => 'Kay pankaka $1-pi shinallami karka, $2 rurakka kayta rurarka.',
'previousrevision'       => 'Ñawpak pachapi panka',
'nextrevision'           => 'Katik killkay',
'currentrevisionlink'    => 'Kunan killkashka',
'cur'                    => 'Kunan',
'last'                   => 'ñawp',
'histlegend'             => "Shukchiykunata maskankapak, ishkay ñawpa pankakunata akllapay, chay kipa \"Enter\" teclata uraypi botontapash suchuchipay.<br />
({{int:cur}}) = ñawpa pankapak kunan pankamanta imashpa shikanmi kan, ({{int:last}})=ashtawan ñawpak pankamanta imashpa shikanmi kan, '''{{int:minoreditletter}}''' = uchilla killkay.",
'history-fieldset-title' => 'Wiñay kawsaypi maskana',
'history-show-deleted'   => 'Pichashkalla',
'histfirst'              => 'Ashtawan ñawpakkuna',
'histlast'               => 'Kipakkuna',

# Revision feed
'history-feed-item-nocomment' => '$1, $2-pi',

# Revision deletion
'rev-delundel'           => 'Rikuchiy/pakay',
'revdel-restore'         => 'Rikuyukkunata shukchina',
'revdel-restore-deleted' => 'pichashka shukchiykuna',
'revdel-restore-visible' => 'Mana pakashka shukchiykuna',

# Merge log
'revertmerge' => 'Shukllachiyta kutichina',

# Diffs
'history-title'           => '"$1" pankapa killkaykunapa wiñay kawsay',
'difference'              => '(imashpa shikan shikanmi kan)',
'lineno'                  => '$1 aspi',
'compareselectedversions' => 'Kay akllashka pankakunaka imashpa mana shinami kapan willana',
'editundo'                => 'Kutichina',
'diff-multi'              => '({{PLURAL:$2|Shuk rurakpa|$2 rurakkunapa}} {{PLURAL:$1|chawpipi shuk mushuk killkayta mana rikuchishkachu|chawpipi $1 mushuk killkaykunata mana rikuchishkachu}})',

# Search results
'searchresults'                    => 'Maskaymanta pankakuna',
'searchresults-title'              => '"$1" maskaymanta pankakuna',
'searchresulttext'                 => '{{SITENAME}}pi maskaymanta ashtawan yachaykunata rikunkapa, [[{{MediaWiki:Helppage}}|{{int:help}}]] rikuripay',
'searchsubtitle'                   => '\'\'\'[[:$1]]\'\'\' pankata maskashkanki ([[Special:Prefixindex/$1|tukuy "$1" killkaywan kallarik pankakuna]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|tukuy "$1" killkaywan kallarik pankakuna]])',
'searchsubtitleinvalid'            => '"$1"-ta maskashkapanki',
'notitlematches'                   => 'Mana shina pankata tiyanchu',
'notextmatches'                    => 'Mana pankaka kay rimaykunata charin',
'prevn'                            => '{{PLURAL:$1|$1}} ñawpak',
'nextn'                            => '{{PLURAL:$1|$1}} katik',
'prevn-title'                      => 'Ñawpak $1 {{PLURAL:$1|maskashka panka|Maskashka pankakuna}}',
'nextn-title'                      => 'Katik $1 {{PLURAL:$1|maskashka panka|Maskashka pankakuna}}',
'shown-title'                      => 'Shuk pankapi $1 {{PLURAL:$1|maskashka panka|maskashka pankakuna}} rikuchina',
'viewprevnext'                     => 'Rikuna ($1 {{int:pipe-separator}} $2) ($3).',
'searchmenu-exists'                => 'Kay wikipi shuk "[[:$1]]" shutiyuk pankaka tiyanmi.',
'searchmenu-new'                   => "'''Kay wikipi \"[[:\$1]]\" shutiyuk pankata kamariy!'''",
'searchprofile-articles'           => 'Yachaykunayuk pankakuna',
'searchprofile-project'            => 'Yanapana ruraykamaypash pankakuna',
'searchprofile-images'             => 'Multimidya',
'searchprofile-everything'         => 'Tukuy',
'searchprofile-advanced'           => 'Yachak rurakkunamanlla',
'searchprofile-articles-tooltip'   => '$1 kitikunapi maskana',
'searchprofile-project-tooltip'    => '$1 kitikunapi maskana',
'searchprofile-images-tooltip'     => 'Archiwukunata maskana',
'searchprofile-everything-tooltip' => 'Tukuy pankakunapi maskana (rimanakuy pankakunapipashmi)',
'searchprofile-advanced-tooltip'   => 'Maykan shuti kitikunapi maskanami kanchikchu akllana',
'search-result-size'               => '$1 ({{PLURAL:$2|1 rimay|$2 rimaykuna}})',
'search-result-category-size'      => '{{PLURAL:$1|1 panka|$1 pankakuna}} ({{PLURAL:$2|1 ushi katikuriya|$2 ushi katikuriyakuna}}, {{PLURAL:$3|1 archiwu|$3 archiwukuna}})',
'search-redirect'                  => '($1-manta pushashka)',
'search-section'                   => '(raki $1)',
'search-suggest'                   => '$1 maskankapa munankichu ?',
'search-interwiki-caption'         => 'Ñaña ruraykamaykuna',
'search-interwiki-default'         => '$1 tarishka imakuna:',
'search-interwiki-more'            => '(ashtawan)',
'search-mwsuggest-enabled'         => 'consejoskunawan',
'search-mwsuggest-disabled'        => 'Mana consejoskunawan',
'searchrelated'                    => 'tinkishka',
'searchall'                        => 'tukuy',
'showingresultsheader'             => "{{PLURAL:$5|Maskashka panka: '''$1''', '''$3'''-manta|Maskashka pankakuna: '''$1 - $2''', '''$3'''-manta}}, '''$4''' maskashpaka",
'nonefound'                        => "'''Musyay''': kikinka mana shina rimakpika, mana tukuy shuti-suyupi maskapanki. 
Icha ''all:'' rimaywan (icha shuk shutisuyupa rimaywan) kikinpa killkata kallarikpika taripankimi.",
'search-nonefound'                 => 'Kikinka maskashka rimaykunaka mana tiyanchu.',
'powersearch'                      => 'Ashtawan alli maskana',
'powersearch-legend'               => 'Ashtawan alli maskana',
'powersearch-ns'                   => 'Chay shutipak kitikunapi maskana :',
'powersearch-redir'                => 'Kutinpushaykunata rikuchiy',
'powersearch-field'                => 'Kayta maskana :',

# Preferences page
'preferences'             => 'Akllaykuna',
'mypreferences'           => 'Ñukapak munaykuna',
'youremail'               => 'E-chaski:',
'yourrealname'            => 'Kikinka kikin shuti:',
'prefs-help-email'        => 'E-chaskita munakpilla ninami kanpanki, shinapash kikinka yaykunapak rimayta kunkakpika E-chaskiwanlla kutin yaykunata ushakripankimi.',
'prefs-help-email-others' => "Kikinka munakpika, shuk rurakkunaka willaykunata shuk kampak rurak pankapi tinkiwan e-chaskita kachawanata ushanka.
Shuk rurakkunaka kikinpa e-chaski ''dirección''ta mana yachankachu.",

# Groups
'group-sysop' => 'Kamachikkuna',

'grouppage-sysop' => '{{ns:project}}:Kamachik',

# User rights log
'rightslog' => 'Rurakpa hayñikunapa kamu',

# Associated actions - in the sentence "You do not have permission to X"
'action-edit' => 'Kay pankapi killkana',

# Recent changes
'nchanges'                        => '$1 {{PLURAL:$1|killkay|killkaykuna}}',
'recentchanges'                   => 'Mushuk killkaykuna',
'recentchanges-legend'            => 'Mushuk killkaykunamanta akllaykuna',
'recentchangestext'               => 'Kay pankapi tukuy mushuk killkaykunata rikukuna',
'recentchanges-feed-description'  => 'Kay willay mayupi ashtawan mushuk killkaykunata rikukuna',
'recentchanges-label-newpage'     => 'Kay killkayka shuk mushuk pankata kamachirka.',
'recentchanges-label-minor'       => 'Kay killkayka uchillami kan',
'recentchanges-label-bot'         => 'Kay killkata shuk killkachik-antakami rurarka',
'recentchanges-label-unpatrolled' => 'Chay killkayka mana kutin rikushkachu kan',
'rcnote'                          => "Kay uraypi {{PLURAL:$1|'''1''' mushuk killkay|'''$1''' mushuk killkaykuna}} kipak {{PLURAL:$2|punchapi|'''$2''' punchakunapi}} ($5, $4 rurashka).",
'rcnotefrom'                      => "Katikka tukuy '''$2''' manta mushuk killkaykunata rikuchinchik ('''$1'''-kamanlla)",
'rclistfrom'                      => '$1-manta mushuk killkaykunata rikuchiy',
'rcshowhideminor'                 => 'uchilla killkaykunata $1',
'rcshowhidebots'                  => "$1 rurana antakuna (''bots'')",
'rcshowhideliu'                   => '$1 shutiyuk rurakkunaka kaypimi kan',
'rcshowhideanons'                 => 'Mana shutiyuk rurakkunata $1',
'rcshowhidepatr'                  => 'rikushka mushuk killkaykunata $1',
'rcshowhidemine'                  => 'Ñukapa killkaykunata $1',
'rclinks'                         => 'Ashtawan mushuk $1 killkaykunata, yallishka $2 punchapi rikuna.<br />$3',
'diff'                            => 'dif',
'hist'                            => 'wñka',
'hide'                            => 'Pakana',
'show'                            => 'Rikuchina',
'minoreditletter'                 => 'u',
'newpageletter'                   => 'M',
'boteditletter'                   => 'r',
'rc-enhanced-expand'              => 'Uchilla imakukunata rikuchina (JavaScript-wanlla)',
'rc-enhanced-hide'                => 'Uchilla imakukunata pakachina',

# Recent changes linked
'recentchangeslinked'          => 'Shukchishka mushuk killkaykuna',
'recentchangeslinked-toolbox'  => 'Tinkishka mushuk killkaykuna',
'recentchangeslinked-title'    => '"$1"-wan tinkishka mushuk killkaykuna',
'recentchangeslinked-noresult' => 'Tinkishka pankakunaka kay akllashka pachipi mana kutin killkashkachu karka.',
'recentchangeslinked-summary'  => "Kay pankaka tukuy shuk pankamanta pushashka pankakunapi (icha tukuy shuk ayllupi tiyak pankakunapi) mushuk killkaykunata rikuchiy. Kikinka shuk pankata [[Special:Watchlist|rikukpika]], chay pankapi mushuk killkaykunata '''yanachishkami''' kanka.",
'recentchangeslinked-page'     => 'Pankapa shuti',
'recentchangeslinked-to'       => 'Ama pankata rikuchina, ranti tukuy kay pankaman tinkiyuk pankakunapi mushuk killkaykunatalla rikuchina',

# Upload
'upload'        => 'Archivuta apamuna',
'uploadlogpage' => 'Apamushka archiwukunapa kamu',
'filedesc'      => 'Uchilla rimay',
'uploadedimage' => '«[[$1]]» apakushka.',

'license'        => 'Licencia:',
'license-header' => 'Licencia',

# File description page
'file-anchor-link'       => 'Archiwu',
'filehist'               => 'Archivupak wiñay kawsay',
'filehist-help'          => "Shuk punchapi ''clic'' rurapay, chay punchapak arichivuta rikunkapa.",
'filehist-revert'        => 'kutichina',
'filehist-current'       => 'kunan',
'filehist-datetime'      => 'Puncha/Pacha',
'filehist-thumb'         => 'Uchilla rikuchiy',
'filehist-thumbtext'     => '$1-pak uchilla rikuchiy',
'filehist-user'          => 'Rurak',
'filehist-dimensions'    => 'Mashna hatun',
'filehist-comment'       => 'Willana',
'imagelinks'             => 'Archivu churapaykuna',
'linkstoimage'           => 'Kay rikchaman {{PLURAL:$1|pankaka|pankakunaka}}  tinkikunata charin:',
'nolinkstoimage'         => 'Nima pankaka kay rikchaman tinkikunchu.',
'sharedupload'           => 'Chay rikchaka $1-mantami kan, icha shuk ruraykamaykunaka paywan llankan',
'sharedupload-desc-here' => 'Chay archiwuka $1-mantami kan, shuk ruraykamaykunaka paywan llankanata ushanmi. Paypa [$2 willanapak pankata] uraypi kutin killkashkami kan.',

# Random page
'randompage' => 'Chunkashpa panka',

# Statistics
'statistics' => 'Kay wikimanta yupaykuna',

'disambiguationspage' => 'Template:Alli killkata akllankapak yanapa',

# Miscellaneous special pages
'nbytes'        => '$1 {{PLURAL:$1|byte|byte}}',
'nmembers'      => '$1 {{PLURAL:$1|panka|pankakuna}}',
'prefixindex'   => 'Tukuy kallarikshutiyuk pankakunaka',
'usercreated'   => '{{GENDER:$3|}}$1 punchapi $2 pachapi kamashka',
'newpages'      => 'Mushuk pankakuna',
'move'          => 'Apakuy',
'movethispage'  => 'Kay pankaman shuk mushuk shutita karana',
'pager-newer-n' => '{{PLURAL:$1|Ashtawan mushuk 1|ashtawan mushuk $1}}',
'pager-older-n' => '{{PLURAL:$1|ashtawan ñawpak 1|ashtawan ñawpak $1}}',

# Book sources
'booksources'               => 'Kamukunapi pukyukuna',
'booksources-search-legend' => 'Kamukunapi pukyukunata maskana',
'booksources-go'            => 'Rina',

# Special:Log
'log' => 'Kamukuna',

# Special:AllPages
'allpages'       => 'Tukuy pankakuna',
'alphaindexline' => '$1-manta $2-man',
'prevpage'       => 'Ñawpak panka ($1)',
'allpagesfrom'   => 'Shinami kallarik pankakunata rikuchiy:',
'allpagesto'     => 'Kaywan tukurik pankakunata rikuchina:',
'allarticles'    => 'Tukuy pankakuna',
'allpagessubmit' => 'Rina',

# Special:Categories
'categories' => 'Katiguriyakuna',

# Special:LinkSearch
'linksearch'      => 'hawaman tinkikunata maskana',
'linksearch-line' => '$1 pankaka $2-manta tinkishkami kan',

# Special:Log/newusers
'newuserlogpage' => 'Rurakkununata kamaykunapa kamu',

# Special:ListGroupRights
'listgrouprights-members' => '(Kay tantanakuypa rurakkunapa shutikuna)',

# Email user
'emailuser' => 'Kay rurakman e-chaskita kachana',

# Watchlist
'watchlist'         => 'Rikukushka pankakuna',
'mywatchlist'       => 'Imata chapakuni',
'watchlistfor2'     => '$1-pak $2',
'watch'             => 'rikupay',
'watchthispage'     => 'Kay pankata rikukuna',
'unwatch'           => 'Ñamana rikuna',
'watchlist-details' => '{{PLURAL:$1|$1 pankata|$1 pankakunata}} rikukunki (rimanakuy pankakunata mana yupakpika).',
'wlshowlast'        => '$1 pachapi, $2 punchapi rurashka $3 mushuk killkaykunata rikuna',
'watchlist-options' => 'rikukushka pankakuna pankapa akllaykuna',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Ñami chay pankata rikukukripanki...',
'unwatching' => 'Ñamana rikukuchishpa...',

# Delete
'deletepage'            => 'kay pankata pichana',
'actioncomplete'        => 'Ñami rurashka',
'actionfailed'          => 'Mana ushanchu',
'deletedtext'           => '"$1" ñami pichashkami kan.
$2 rikpika, ima pankakunaka pichashkami kan yachakupanki.',
'dellogpage'            => 'Pichaykunapa kamu',
'deletecomment'         => 'Imashpa:',
'deleteotherreason'     => 'Yapa imashpa:',
'deletereasonotherlist' => 'Yapa imashpa',

# Rollback
'rollbacklink' => 'Kutichina',

# Protect
'protectlogpage'              => 'Wichkaykunapak kamu',
'protectedarticle'            => '[[$1]]-ta wichkachirka',
'protectcomment'              => 'Imashpa:',
'protectexpiry'               => 'Ima pachakaman:',
'protect_expiry_invalid'      => "''Ima pachakaman'' mana alli nishkami.",
'protect_expiry_old'          => "''Ima pachakaman'' mana alli nishkami : kay pachaka ñawpak pachapi kapanmi !",
'protect-default'             => 'Rukuy runakunaman ari nipay',
'protect-fallback'            => '«$1» hayñiyuk rurakkunallapak',
'protect-level-autoconfirmed' => 'Kikin shutiyuk rurakkunallapak',
'protect-level-sysop'         => 'Kipukamayukkunallapak',
'protect-expiring'            => '$1 (UTC) pachakaman',
'restriction-type'            => 'Hayñi:',

# Undelete
'undeletelink'     => 'Rikuna/pakarina',
'undeleteviewlink' => 'rikuna',

# Namespace form on various pages
'namespace'      => 'Shutipak kiti',
'invert'         => 'akllayta tikrachina',
'blanknamespace' => 'Kapak',

# Contributions
'contributions'       => 'Kay rurakpa killkaykuna',
'contributions-title' => '$1 shutiyuq rurakpa killkaykuna',
'mycontris'           => 'Nukapak killkaykuna',
'contribsub2'         => '$1 ($2)',
'uctop'               => ' (kipak killkay)',
'month'               => 'Kay killamanta (ñawpakmantapash):',
'year'                => 'Kay watamanta (ñawpakmantapash) :',

'sp-contributions-newbies'  => 'Mushuk rurakkunapallami killkaykunata rikuchiy',
'sp-contributions-blocklog' => 'Wichkaykunapa kamu',
'sp-contributions-uploads'  => 'apamuykuna',
'sp-contributions-logs'     => 'kamukuna',
'sp-contributions-talk'     => 'rimanakuy',
'sp-contributions-search'   => 'Killkachiykunata maskana',
'sp-contributions-username' => 'IP yupay icha rurakpa shuti:',
'sp-contributions-toponly'  => 'Ashtawan mushuk killkaykunallatami rikuchina',
'sp-contributions-submit'   => 'Maskana',

# What links here
'whatlinkshere'            => 'Kayman tinkikuna',
'whatlinkshere-title'      => '$1-man tinkiyuk pankakuna',
'whatlinkshere-page'       => 'Panka:',
'linkshere'                => "Chay pankakunaka '''[[:$1]]'''-man tinkiyukmi kan:",
'nolinkshere'              => "Mana pankaka '''[[:$1]]'''-man tinkikunchu.",
'isredirect'               => 'pushashka panka',
'istemplate'               => "Ukupi tiyak panka (''inclusión'')",
'isimage'                  => 'rikcha tinki',
'whatlinkshere-prev'       => '{{PLURAL:$1|ñawpak|$1 ñawpak}}',
'whatlinkshere-next'       => '{{PLURAL:$1|katik|$1 katik}}',
'whatlinkshere-links'      => 'tinkikuna',
'whatlinkshere-hideredirs' => '$1 kutinpushakkuna',
'whatlinkshere-hidetrans'  => '$1 plantillapa uku tiyakkunata',
'whatlinkshere-hidelinks'  => '$1 tinkikuna',
'whatlinkshere-hideimages' => '$1 rikchaman tinkikuna',
'whatlinkshere-filters'    => 'Susunakuna',

# Block/unblock
'blockip'                  => 'Rurakta wichkana',
'ipboptions'               => '2 pacha:2 hours, 1 puncha:1 day, 3 puncha:3 days, 1 simana:1 week, 2 simana:2 weeks, 1 killa:1 month, 3 killa:3 months, 6 killa:6 months,1 pacha:1 year,Tukuy kawsayman:infinite',
'ipblocklist'              => 'Wichkashka rurakkuna',
'blocklink'                => 'Wichkana',
'unblocklink'              => 'Ñamana wichkana',
'change-blocklink'         => 'Wichkayta shukchisna',
'contribslink'             => 'llankaykuna',
'blocklogpage'             => 'Wichkaykunapa kamu',
'blocklogentry'            => '[[$1]]-ta chay pachakaman wichkarka: $2 $3',
'unblocklogentry'          => '$1 rurakpa wichkayta kishpichirka',
'block-log-flags-nocreate' => 'Mushuk rurak shutipa kamayta wichkashkami',

# Move page
'movearticle'    => 'Kay pankama mushuk shutita karapana:',
'newtitle'       => 'Kay mushuk shutiman',
'move-watch'     => 'Kay ishkay pankakunata rikukuna',
'movepagebtn'    => 'Kay pankaman mushuk shutita karapana:',
'pagemovedsub'   => 'Shutita ñami shukchishka',
'movepage-moved' => '\'\'\'"$1" pankaka "$2"shutiman apakushka\'\'\'',
'articleexists'  => 'Shuk pankaka ñami kay shutita charin, icha kay shutiyuk man alli kan.
Shuk shutita akllapay.',
'talkexists'     => 'Kay pankapa shutita ñami shukchishkami kan, shinapash paypa rimanakuyta shuk rimanakuyka ñami tiyakpika mana apamushkami kan : makillawan kay ishkay rimanakuykunata tantachipay.',
'movedto'        => 'Kayman apakushka :',
'movetalk'       => 'Tinkishka rimanakuyta shinalla apakuna',
'movelogpage'    => 'Shutikunata shukchiykunapa kamu',
'movereason'     => 'Imashpa:',
'revertmove'     => 'Kutichina',

# Export
'export' => 'Pankakunata apakuna',

# Namespace 8 related
'allmessagesname'    => 'Shuti',
'allmessagesdefault' => 'Ñawpak killka',

# Thumbnails
'thumbnail-more'  => 'hatunchina',
'thumbnail_error' => 'Uchilla rikchata kamanata kaymanta mana usharkanchikchu: $1',

# Tooltip help for the actions
'tooltip-pt-userpage'             => 'Kanpak rurak panka',
'tooltip-pt-mytalk'               => 'Kanpak rimanakuy',
'tooltip-pt-preferences'          => 'munaykuna',
'tooltip-pt-watchlist'            => 'Chay pankakunapa mushuk killkaykunata rikukupanki',
'tooltip-pt-mycontris'            => 'Tukuy kanpak killkaykuna',
'tooltip-pt-login'                => 'Ashtawan alli llankankapa, shuk rurak shutita akllanata ushankimi',
'tooltip-pt-logout'               => 'Llukshina',
'tooltip-ca-talk'                 => 'Kay pankamanta rimanakuna',
'tooltip-ca-edit'                 => 'Kay pankapi killkanata ushapanki. "Ñawpak rikuy" clic rurapay, chay kipa kikinpa killkaykunata churapay',
'tooltip-ca-addsection'           => 'Shuk mushuk rakita kamana',
'tooltip-ca-viewsource'           => 'Chay pankaka wichkashkami kan, rikunallata, mana killkanata ushapanki',
'tooltip-ca-history'              => 'Kay pankapak ñawpak killkanakuna, killkakkunapash',
'tooltip-ca-protect'              => 'Kay pankata wichkana',
'tooltip-ca-delete'               => 'Kay pankata pichana',
'tooltip-ca-move'                 => 'Kay pankaman shuk mushuk shutita karana',
'tooltip-ca-watch'                => 'Kay pankata rikukuna',
'tooltip-ca-unwatch'              => 'Kay pankata ñamana rikukuna',
'tooltip-search'                  => 'Kay wikipi maskana',
'tooltip-search-go'               => 'Shuk shinami shutiyuk panka tiyakpika, chayman rina',
'tooltip-search-fulltext'         => 'Kay rimaylunata pankakunapi maskana',
'tooltip-p-logo'                  => 'Kapak pankaman rina',
'tooltip-n-mainpage'              => 'Kapak pankaman rina',
'tooltip-n-mainpage-description'  => 'Kapak pankaman rina',
'tooltip-n-portal'                => 'Proyectomanta, imata ruranata ushanki, maypi willaykunata tiyanchu',
'tooltip-n-currentevents'         => 'Kunan pachapi willaykuna',
'tooltip-n-recentchanges'         => 'Kay wikipi kunan llankaykuna',
'tooltip-n-randompage'            => 'Chunkashka pankaman rina',
'tooltip-n-help'                  => 'Yachakunkapa uku',
'tooltip-t-whatlinkshere'         => 'Kay pankaman tutuy tinkiyuk pankakuna',
'tooltip-t-recentchangeslinked'   => 'kay pankaman tinkiyuk pankakunapi mushuk killkaykuna',
'tooltip-feed-rss'                => 'Kay pankapa RSS mikuchiy',
'tooltip-feed-atom'               => 'Sindicación Atom de esta página',
'tooltip-t-contributions'         => 'Kay rurakpa killkaykunata rikuna',
'tooltip-t-emailuser'             => 'Kay rurakman e-chaskita kachana',
'tooltip-t-upload'                => 'Rikchakunata, multimidiya archivukunata apakuna',
'tooltip-t-specialpages'          => 'Tukuy sapak pankakuna',
'tooltip-t-print'                 => 'Kay pankata impresoraman tikrachinkapa',
'tooltip-t-permalink'             => 'Enlace permanente a esta versión de la página',
'tooltip-ca-nstab-main'           => 'Pankata rikuna',
'tooltip-ca-nstab-user'           => 'Chay rurakpa pankata rikuna',
'tooltip-ca-nstab-special'        => 'Kayka shuk sapak pankami kan, kaypi killkanata mana ushanki',
'tooltip-ca-nstab-project'        => 'Ruraykamay pankata rikuna',
'tooltip-ca-nstab-image'          => 'Kay rikchapak pankaman rina',
'tooltip-ca-nstab-template'       => 'Plantillata rikuna',
'tooltip-ca-nstab-category'       => 'Samiyachiymanta pankata rikuna',
'tooltip-minoredit'               => 'Kay killkayta uchillami nina',
'tooltip-save'                    => 'Mushuk killkaykunata churana',
'tooltip-preview'                 => 'Kikinpa mushuk killkaykuna : paykunata churankapak ñawpak rikupay ari !',
'tooltip-diff'                    => 'Kay pankapi kikinpak mushuk killkaykunata rikuchina',
'tooltip-compareselectedversions' => 'Kay ishkay akllashka pankunapura tukuy mana shinami imakunata rikuchiy',
'tooltip-watch'                   => 'Kay pankata rikukuna',
'tooltip-rollback'                => '"Kutichina" nikpika, shuk rurakpa tukuy ashtawan kipa killkaykunata kutichipanki',
'tooltip-undo'                    => '"Kutichina" nikpika, kay hapishka killkayta kutichipanki, shinalla killkana pankapa "ñawpak rikuchiy" rikupanki : chaymanta, imashpa kay killkayta kutichipankichu rimanata ushapanki',
'tooltip-summary'                 => 'Uchilla willayta killkana',

# Browsing diffs
'previousdiff' => 'Yallik ñawpakmi killkay',
'nextdiff'     => 'Yalli mushukmi killkay',

# Media information
'file-info-size' => '$1 × $2 tawakukuna (pixelkuna); $3 llashakmi kan; MIME sami: $4',
'file-nohires'   => 'Kay rikchapa shuk yallik hatun rikuchiyka mana tiyanchu.',
'svg-long-desc'  => 'SVG archiwuka, $1 × $2 tawakukunayuk rimashka, $3 llashakmi.',
'show-big-image' => 'Yallik hatun rikuchipay',

# Bad image list
'bad_image_list' => 'Kay shina killkanami kapanki:
Tukuy aspikunaka kuyllurwan (*) kallarinami kan
Shuk aspipi, shukniki tinkika ima tinkita wichkashkami kanka nin, kay aspipi shuk tinkikunapi ima pankakunapi wichkashka tinkita charinata ushanmi nin.',

# Metadata
'metadata'          => 'Metadata',
'metadata-help'     => 'Chay rikchaka yapa willaykunata charin, icha camara antamanta shinalla shuk suyuchik antamanta. Rikchata shukchishkami kakpika, icha kay willaykunaka mana alli kan.',
'metadata-expand'   => 'Uchilla willaykunata rikuchiy',
'metadata-collapse' => 'Uchilla willaykunata pakay',
'metadata-fields'   => 'Kaypi killkashka rikchamanta willaykunaka wiñay paypa rikchawan rikuchishkami kanka. Shuk willaykunata pakashkami kanka. Shinapash shuk rurakka munakpika paykunaya rikunata ushanka.
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength
* artist
* copyright
* imagedescription
* gpslatitude
* gpslongitude
* gpsaltitude',

# External editor support
'edit-externally'      => 'Kay archiwuta shuk hawa antanawan llankana',
'edit-externally-help' => 'Ashtawan yachakunkakak [//www.mediawiki.org/wiki/Manual:External_editors kay yanapata] (inlish shimipi) killkakatipay',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'tukuy',
'namespacesall' => 'tukuy',
'monthsall'     => 'tukuy',

# Watchlist editing tools
'watchlisttools-view' => 'Mushuk killkaykunata rikuna',
'watchlisttools-edit' => 'Rikukushka pankakunata rikuna, shukchinapash',
'watchlisttools-raw'  => 'Mana yanapawan rikukushka pankakunata akllapay',

# Core parser functions
'duplicate-defaultsort' => "'''Rikupay''': Kikinmanta ordenankapak llawita «$2» ñawpak pachamanta «$1» llawita pichankami.",

# Special:SpecialPages
'specialpages' => 'Sapak pankakuna',

# External image whitelist
'external_image_whitelist' => "  #Kay aspita kay shinallami sakipay<pre>
#Uraypi ''regex'' samikunata churapay (// chawpipilla)
#Kay samikunaka hawa rikchakunapa URLwan taripachishkami kanka.
#Alli taripashkakunaka rikcha shinami rikushishkami kanka, shukkunaka tinki shinallami riksichinka, 
#«#» llikawan kallarik aspikunaka willaykunallami kanka
#Uchilla, hatun llikakunatapash churanata ushapanki, kaypi shinallami kan

#Tukuy regex samikunata kay aspi hawapi churapay. Kay aspita kay shinallami sakipay</pre>",

# Special:Tags
'tag-filter' => '[[Special:Tags|Wipalakunapa]] susuna:',

);
